# CHANGELOG

## v0.2.0 (September 05, 2024)

-   Features
    -   Added the command-line `epistolary` tool, which can be used to interact with the package from the command line (#6)
-   Housekeeping
    -   Added GitHub Actions CI/CD for PyPI
